==> zope.app.securitypolicy-3.4.5.tar.gz: zope.app.securitypolicy-3.4.5/setup.py <==
##############################################################################
#
# Copyright (c) 2006 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Setup for zope.app.securitypolicy package

$Id: setup.py 81329 2007-10-31 19:53:46Z srichter $
"""

import os

from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

setup(name='zope.app.securitypolicy',
    version = '3.4.5',
    author='Zope Corporation and Contributors',
    author_email='zope3-dev@zope.org',
    description="Zope's Default Security Policy ZMI Support",
    long_description=(
        read('README.txt')
        + '\n\n' +
        read('CHANGES.txt')
        ),
    keywords = "zope3 security policy",
    classifiers = [
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Zope Public License',
        'Programming Language :: Python',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
        'Framework :: Zope3'],
    url='http://pypi.python.org/pypi/zope.app.securitypolicy',
    license='ZPL 2.1',
    packages=find_packages('src'),
    package_dir = {'': 'src'},
    namespace_packages=['zope', 'zope.app'],
    extras_require = dict(test=['zope.app.testing']),
    install_requires=['setuptools',
                      'zope.annotation',
                      'zope.app.form',
                      'zope.app.security',
                      'zope.component [hook]',
                      'zope.configuration',
                      'zope.exceptions',
                      'zope.i18n',
                      'zope.i18nmessageid',
                      'zope.interface',
                      'zope.location',
                      'zope.schema',
                      'zope.security',
                      'zope.securitypolicy',
                      ],
    include_package_data = True,
    zip_safe = False,
    )

==> zope.app.securitypolicy-3.5.1.tar.gz: zope.app.securitypolicy-3.5.1/setup.py <==
##############################################################################
#
# Copyright (c) 2006 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Setup for zope.app.securitypolicy package

$Id: setup.py 95178 2009-01-27 13:23:50Z wosc $
"""

import os

from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

setup(name='zope.app.securitypolicy',
    version = '3.5.1',
    author='Zope Corporation and Contributors',
    author_email='zope3-dev@zope.org',
    description="Zope's Default Security Policy ZMI Support",
    long_description=(
        read('README.txt')
        + '\n\n' +
        read('CHANGES.txt')
        ),
    keywords = "zope3 security policy",
    classifiers = [
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Zope Public License',
        'Programming Language :: Python',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
        'Framework :: Zope3'],
    url='http://pypi.python.org/pypi/zope.app.securitypolicy',
    license='ZPL 2.1',
    packages=find_packages('src'),
    package_dir = {'': 'src'},
    namespace_packages=['zope', 'zope.app'],
    extras_require = dict(test=['zope.app.testing',
                                'zope.app.zcmlfiles',
                                ]),
    install_requires=['setuptools',
                      'zope.annotation',
                      'zope.browser',
                      'zope.app.form',
                      'zope.app.security',
                      'zope.component [hook]',
                      'zope.configuration',
                      'zope.exceptions',
                      'zope.i18n',
                      'zope.i18nmessageid >= 3.4.2',
                      'zope.interface',
                      'zope.location',
                      'zope.schema',
                      'zope.security',
                      'zope.securitypolicy',
                      ],
    include_package_data = True,
    zip_safe = False,
    )
